#ifndef CUSTOM_TRACKER_VIS_XTYPEINFO_H
# define CUSTOM_TRACKER_VIS_XTYPEINFO_H

//<<<<<< INCLUDES                                                       >>>>>>

# include "Visualisation/CustomTracker/interface/config.h"
# include "Ig_Modules/IgCommonData/interface/xtypeinfo.h"

//<<<<<< PUBLIC DEFINES                                                 >>>>>>
//<<<<<< PUBLIC CONSTANTS                                               >>>>>>
//<<<<<< PUBLIC TYPES                                                   >>>>>>

class VisCuTkTwig;
class VisCuTrackerSelectionTwig;
class VisCuTkSlThetaPhiTwig;
class VisCuTkSlRecTracksTwig;
class VisCuTkSlSimTracksTwig;
class VisCuTkEvTrackerTwig;
class VisCuTkEvRecHitsTwig;
class VisCuTkEvRecTracksTwig;
class VisCuTkEvSimHitsTwig;
class VisCuTkEvSimTracksTwig;
class VisCutkMapTrackerTwig;
class VisCuTkMapRecHitsTwig;
class VisCuTkMapSimHitsTwig;

//<<<<<< PUBLIC VARIABLES                                               >>>>>>
//<<<<<< PUBLIC FUNCTIONS                                               >>>>>>
//<<<<<< CLASS DECLARATIONS                                             >>>>>>

XTYPEINFO_DECLARE (CUSTOM_TRACKER_VIS_API, VisCuTkTwig);
XTYPEINFO_DECLARE (CUSTOM_TRACKER_VIS_API, VisCuTrackerSelectionTwig);
XTYPEINFO_DECLARE (CUSTOM_TRACKER_VIS_API, VisCuTkSlThetaPhiTwig);
XTYPEINFO_DECLARE (CUSTOM_TRACKER_VIS_API, VisCuTkSlRecTracksTwig);
XTYPEINFO_DECLARE (CUSTOM_TRACKER_VIS_API, VisCuTkSlSimTracksTwig);
XTYPEINFO_DECLARE (CUSTOM_TRACKER_VIS_API, VisCuTkEvTrackerTwig);
XTYPEINFO_DECLARE (CUSTOM_TRACKER_VIS_API, VisCuTkEvRecHitsTwig);
XTYPEINFO_DECLARE (CUSTOM_TRACKER_VIS_API, VisCuTkEvRecTracksTwig);
XTYPEINFO_DECLARE (CUSTOM_TRACKER_VIS_API, VisCuTkEvSimHitsTwig);
XTYPEINFO_DECLARE (CUSTOM_TRACKER_VIS_API, VisCuTkEvSimTracksTwig);
XTYPEINFO_DECLARE (CUSTOM_TRACKER_VIS_API, VisCuTkMapTrackerTwig);
XTYPEINFO_DECLARE (CUSTOM_TRACKER_VIS_API, VisCuTkMapRecHitsTwig);
XTYPEINFO_DECLARE (CUSTOM_TRACKER_VIS_API, VisCuTkMapSimHitsTwig);


//<<<<<< INLINE PUBLIC FUNCTIONS                                        >>>>>>
//<<<<<< INLINE MEMBER FUNCTIONS                                        >>>>>>

#endif // CUSTOM_TRACKER_VIS_XTYPEINFO_H
